@@ -12,11 +12,16 @@ function(formula, data,...,subset,na.action=na.rpart){
   m$na.action <- na.action
   m[[1]] <- as.name("model.frame")
   m <- eval(m, parent.frame())
-  
   Terms = attr(m, "terms")
   y = as.vector(model.extract(m,"response"))
   preds<-attr(attributes(m)$terms,"term.labels")
-  x<-as.data.frame(m[,!is.na(match(names(m),preds))])
+  if(length(preds)==1){
+    vec=m[,!is.na(match(names(m),preds))]
+    x<-data.frame(x=vec)
+    names(x)=preds
+  }else{
+    x<-as.data.frame(m[,!is.na(match(names(m),preds))])
+  }
   res = ada.default(x,y,...,na.action=na.action)
   res$terms = Terms
   cl = match.call()
